@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:59:42
-@LastEditTime: 2021-08-17 13:56:06
+@LastEditTime: 2021-09-10 11:35:18
 @LastEditors: HuangJianYi
 :description: 
 """
-__all__ = ["address", "user", "theme", "ip", "app", "act", "goods","order","task"]
+__all__ = ["address", "user", "theme", "ip", "app", "act", "goods","order","task","stat"]
