@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-09 17:46:15
+@LastEditTime: 2021-09-14 19:41:31
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -20,7 +20,6 @@ from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
-from seven_cloudapp_frame.models.db_models.middler.middler_product_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.operation.operation_log_model import *
 
@@ -79,12 +78,11 @@ class FrameBaseHandler(BaseApiHandler):
         decode_string = str(base64.b64decode(source), 'utf-8')
         return decode_string
 
-    def get_request_param(self, param_name, default="", strip=True):
+    def get_param(self, param_name, default="", strip=True):
         """
         :description: 二次封装获取参数
         :param param_name: 参数名
         :param default: 如果无此参数，则返回默认值
-        :param filter_sql: 是否过滤sql关键字
         :return: 参数值
         :last_editors: HuangJianYi
         """
@@ -307,15 +305,8 @@ class FrameBaseHandler(BaseApiHandler):
         :return app_key, app_secret
         :last_editors: HuangJianYi
         """
-        request_app_key = int(self.get_param("app_key", 0))
         app_key = config.get_value("app_key")
         app_secret = config.get_value("app_secret")
-
-        if request_app_key not in (0, app_key):
-            middler_product_dict = MiddlerProductModel(context=self).get_cache_dict("app_key=%s", field="app_secret", params=[request_app_key])
-            if middler_product_dict:
-                app_key = request_app_key
-                app_secret = middler_product_dict["app_secret"]
         return app_key, app_secret
 
     def set_default_headers(self):
@@ -434,6 +425,8 @@ class TaoBaseHandler(FrameBaseHandler):
                     app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", field="app_id", params=store_user_nick)
                     if app_info_dict:
                         app_id = app_info_dict["app_id"]
+            else:
+                app_id = config.get_value("test_source_app_id")
         return app_id
 
     def get_is_test(self):
@@ -536,8 +529,8 @@ class ClientBaseHandler(FrameBaseHandler):
             return
 
         dict_par = {}
-        dict_par["open_id"] = self.get_request_param("user_id")
-        dict_par["app_id"] = self.get_request_param("app_id","1")
+        dict_par["open_id"] = self.get_param("user_id")
+        dict_par["app_id"] = self.get_param("app_id","1")
 
         try:
             # 将设备信息字符串转为字典类型
@@ -545,7 +538,7 @@ class ClientBaseHandler(FrameBaseHandler):
             if clientheaderinfo_string:
                 self.device_info_dict = self.device_info_dict(clientheaderinfo_string)
 
-            user_id = self.get_request_param("user_id")
+            user_id = self.get_param("user_id")
             if user_id:
                 # 频繁请求校验
                 is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_par["app_id"], user_id)
@@ -581,6 +574,50 @@ class ClientBaseHandler(FrameBaseHandler):
         return device_info_dict
 
 
+def filter_check_params(must_params=None):
+    """
+    :description: 参数过滤装饰器 仅限handler使用,
+                  提供参数的检查及获取参数功能
+                  装饰器使用方法:
+                  @client_filter_check_params("param_a,param_b,param_c")  或
+                  @client_filter_check_params(["param_a","param_b,param_c"])
+                  参数获取方法:
+                  self.request_params[param_key]
+    :param must_params: 必须传递的参数集合
+    :last_editors: HuangJianYi
+    """
+    def check_params(handler):
+        def wrapper(self, **args):
+            self.request_params = {}
+            if type(must_params) == str:
+                must_array = must_params.split(",")
+            if type(must_params) == list:
+                must_array = must_params
+            if self.request.method == "POST" and self.request.body:
+                json_params = {}
+                try:
+                    json_params = json.loads(self.request.body)
+                except:
+                    self.response_json_error("ParamError", "参数错误,缺少必传参数")
+                    return
+                if json_params:
+                    for field in json_params:
+                        self.request_params[field] = json_params[field]
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_param(field)
+            if must_params:
+                for must_param in must_array:
+                    if not must_param in self.request_params or self.request_params[must_param] == "":
+                        self.response_json_error("ParamError", "参数错误,缺少必传参数")
+                        return
+            return handler(self, **args)
+
+        return wrapper
+
+    return check_params
+
+
 def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     :description: 头部过滤装饰器 仅限handler使用
