@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-09-06 15:12:16
+@LastEditTime: 2021-09-06 15:24:46
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -195,7 +195,11 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         try:
-            acquire_lock_name = f"queueup_queue:{queue_name}"
+            acquire_lock_name = f"queueup_queue"
+            if app_id:
+                acquire_lock_name += "_" + str(app_id)
+            acquire_lock_name += ":" + str(queue_name)
+
             acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
             if acquire_lock_status == False:
                 invoke_result_data.success = False
@@ -287,7 +291,11 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         try:
-            if SevenHelper.is_continue_request(f"queueup_pop:{queue_name}_{user_id}",expire=1*1000) == True:
+            cache_key = f"queueup_pop"
+            if app_id:
+                cache_key += "_" + str(app_id)
+            cache_key += ":" + str(queue_name) + "_" + str(user_id)
+            if SevenHelper.is_continue_request(cache_key, expire=1 * 1000) == True:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "对不起,请1秒后再试"
