@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-09-10 11:12:56
+@LastEditTime: 2021-09-14 19:21:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -23,82 +23,96 @@ class TikTokHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self, code="", anonymous_code=""):
+    def code2_session(self, app_id, app_secret, code="", anonymous_code=""):
         """
         :description:获取open_id、session_key等信息
+        :param app_id: app_id
+        :param app_secret: app_secret
         :param code: 登录票据,非匿名需要 code
         :param anonymous_code: 非匿名下的 anonymous_code 用于数据同步，匿名需要 anonymous_code
         :return: 
         :last_editors: HuangJianYi
         """
-        redis_key = "tiktok_login_code:" + str(code)
+        invoke_result_data = InvokeResultData()
+        redis_key = f"{app_id}_tiktok_login_code:{code}"
         redis_init = SevenHelper.redis_init()
         code2_session_dict = redis_init.get(redis_key)
         if code2_session_dict:
             code2_session_dict = SevenHelper.json_loads(code2_session_dict)
-            return code2_session_dict
-        app_id = config.get_value("app_id")
-        app_secret = config.get_value("app_secret")
+            invoke_result_data.data = code2_session_dict
+            return invoke_result_data
         param = {
             'code': code,  # 用户点击按钮跳转到抖音授权页, 抖音处理完后重定向到redirect_uri, 并给我们加上code=xxx的参数, 这个code就是我们需要的
             'appid': app_id,
             'secret': app_secret,
             'anonymous_code': anonymous_code,
         }
-
-        # 通过code获取access_token
-        requset_url = 'https://developer.toutiao.com/api/apps/jscode2session'
-        resp = None
+        response = None
         try:
-            resp = requests.get(requset_url, params=param)
-            res_result = json.loads(resp.text)
-            open_id = res_result['openid']
-            session_key = res_result['session_key']
-            redis_init.set(redis_key, SevenHelper.json_dumps(res_result), ex=60 * 60)
-            redis_init.set(f"tiktok_sessionkey:{str(open_id)}", session_key, ex=60 * 60)
-            return res_result
+            requset_url = 'https://developer.toutiao.com/api/apps/jscode2session'
+            headers = {"Content-type": "application/json"}
+            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data["err_no"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["err_no"]
+                invoke_result_data.error_message = response_data["err_tips"]
+                return invoke_result_data
+            open_id = response_data["data"]['openid']
+            session_key = response_data["data"]['session_key']
+            redis_init.set(redis_key, SevenHelper.json_dumps(response_data["data"]), ex=60 * 60)
+            redis_init.set(f"{app_id}_tiktok_sessionkey:{str(open_id)}", session_key, ex=60 * 60)
+            invoke_result_data.data = response_data
+            return invoke_result_data
         except Exception as ex:
-            self.logger_error.error(str(ex) + "【code2_session】" + str(resp.text))
-            return {}
+            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = str(ex)
+            return invoke_result_data
 
     @classmethod
-    def get_access_token(self, grant_type="client_credential"):
+    def get_access_token(self,app_id, app_secret, grant_type="client_credential"):
         """
         :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :param app_id: app_id
+        :param app_secret: app_secret
         :param grant_type: 获取access_token 时值为 client_credential
         :return: 
         :last_editors: HuangJianYi
         """
-        redis_key = "tiktok_access_token"
-        redis_init = SevenHelper.redis_init()
-        access_token_dict = redis_init.get(redis_key)
-        if access_token_dict:
-            access_token_dict = SevenHelper.json_loads(access_token_dict)
-            return access_token_dict
-        app_id = config.get_value("app_id")
-        app_secret = config.get_value("app_secret")
+        invoke_result_data = InvokeResultData()
         param = {
             'appid': app_id,
             'secret': app_secret,
             'grant_type': grant_type,
         }
-
-        # 通过code获取access_token
-        requset_url = 'https://developer.toutiao.com/api/apps/token'
-        resp = None
+        response = None
         try:
-            resp = requests.get(requset_url, params=param)
-            redis_init.set(redis_key, resp, ex=60 * 60)
-            res_result = json.loads(resp.text)
-            return res_result
+            requset_url = 'https://developer.toutiao.com/api/apps/token'
+            headers = {"Content-type": "application/json"}
+            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data["err_no"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["err_no"]
+                invoke_result_data.error_message = response_data["err_tips"]
+                return invoke_result_data
+            invoke_result_data.data = response_data["data"]
+            return invoke_result_data
         except Exception as ex:
-            self.logger_error.error(str(ex) + "【get_access_token】" + str(resp.text))
-            return {}
+            self.logger_error.error("【get_access_token】" + str(ex) + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = str(ex)
+            return invoke_result_data
 
     @classmethod
-    def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv):
+    def decrypt_data_by_code(self, app_id, app_secret, open_id, code, encrypted_Data, iv):
         """
         :description:解析加密数据，客户端判断是否登录状态，如果登录只传open_id不传code，如果是登录过期,要传code重新获取session_key
+        :param app_id: app_id
+        :param app_secret: app_secret
         :param open_id：open_id
         :param code：登录票据
         :param encrypted_Data：加密数据,抖音返回加密参数
@@ -108,17 +122,16 @@ class TikTokHelper:
         """
         data = {}
         if code:
-            code2_session_dict = self.code2_session(code)
+            code2_session_dict = self.code2_session(app_id, app_secret, code)
             if code2_session_dict:
                 open_id = code2_session_dict["openid"]
         try:
-            session_key = SevenHelper.redis_init().get(f"tiktok_sessionkey:{str(open_id)}")
+            session_key = SevenHelper.redis_init().get(f"{app_id}_tiktok_sessionkey:{str(open_id)}")
             app_id = config.get_value("app_id")
             data_crypt = TikTokBizDataCrypt(app_id, session_key)
             data = data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error(str(ex) + "【decrypt_data_by_code】")
-
+            self.logger_error.error("【decrypt_data_by_code】" + str(ex))
         return data
 
     @classmethod
@@ -138,40 +151,49 @@ class TikTokHelper:
             #data中是解密的信息
             data = data_crypt.decrypt(encrypted_Data, iv)
         except Exception as ex:
-            self.logger_error.error(str(ex) + "【decrypt_data】")
+            self.logger_error.error("【decrypt_data】" + str(ex))
         return data
 
-
-class TikTokBizDataCrypt:
-    def __init__(self, app_id, session_key):
-        self.app_id = app_id
-        self.session_key = session_key
-
-    def decrypt(self, encryptedData, iv):
+    @classmethod
+    def create_qr_code(self, access_token, appname="douyin", path="", width=430, line_color={ "r": 0, "g": 0, "b": 0 }, background={ "r": 255, "g": 255, "b": 255 }):
         """
-        :description: 解密
-        :param encryptedData: encryptedData
-        :param iv: iv
-        :return str
+        :description:获取小程序/小游戏的二维码。该二维码可通过任意 app 扫码打开，能跳转到开发者指定的对应字节系 app 内拉起小程序/小游戏， 并传入开发者指定的参数。通过该接口生成的二维码，永久有效，暂无数量限制。
+        :param access_token: 服务端 API 调用标识
+        :param appname: 打开二维码的字节系 app 名称
+        :param path: 小程序/小游戏启动参数，小程序则格式为 encode({path}?{query})，小游戏则格式为 JSON 字符串，默认为空
+        :param width: 二维码宽度，单位 px，最小 280px，最大 1280px，默认为 430px
+        :param line_color: 二维码线条颜色，默认为黑色
+        :param background: 二维码背景颜色，默认为白色
+        :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
-        # base64 decode
-        session_key = base64.b64decode(self.session_key)
-        encryptedData = base64.b64decode(encryptedData)
-        iv = base64.b64decode(iv)
-        decrypted = {}
-        cipher = AES.new(session_key, AES.MODE_CBC, iv)
-        result_data = str(self._unpad(cipher.decrypt(encryptedData)), "utf-8")
-        if result_data:
-            decrypted = json.loads(result_data)
-        if decrypted:
-            if decrypted['watermark']['appid'] != self.app_id:
-                raise Exception('Invalid Buffer')
-
-        return decrypted
-
-    def _unpad(self, s):
-        return s[:-ord(s[len(s) - 1:])]
+        invoke_result_data = InvokeResultData()
+        param = {
+                "appname": appname,
+                "access_token": access_token,
+                "path": path,
+                "width": width,
+                "line_color": line_color,
+                "background": background
+                }
+        response = ""
+        try:
+            requset_url = 'https://developer.toutiao.com/api/apps/token'
+            headers = {"Content-type": "application/json"}
+            response = requests.post(requset_url, headers=headers, data=SevenHelper.json_dumps(param))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["err_no"]
+                invoke_result_data.error_message = response_data["err_tips"]
+                return invoke_result_data
+            return response_data
+        except Exception as ex:
+            self.logger_error.error("【create_qr_code】" + str(ex) + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = str(ex)
+            return invoke_result_data
 
 
 class TikTokPayRequest(object):
@@ -183,31 +205,33 @@ class TikTokPayRequest(object):
     api_key = ""
     #开发者自定义字段，回调原样回传
     cp_extra = ""
-    #商户自定义回调地址
-    notify_url = ""
+    #支付回调地址
+    pay_notify_url = ""
+    #退款回调地址
+    refund_notify_url = ""
     #担保交易Token（令牌）
     token = ""
-    #担保交易盐值
+    #担保交易密钥
     salt = ""
     # 日志
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self):
+    def __init__(self, app_id, api_key, cp_extra, token, salt):
         """
         :description: 初始化
         :last_editors: HuangJianYi
         """
-        payconfig = config.get_value("tiktok_pay")
-        self.app_id = config.get_value("app_id")
-        self.api_key = payconfig['api_key']
-        self.cp_extra = payconfig['cp_extra']
-        self.notify_url = payconfig['notify_url']
-        self.token = payconfig['token']
-        self.salt = payconfig['salt']
+        self.app_id = app_id
+        self.api_key = api_key
+        self.cp_extra = cp_extra
+        self.token = token
+        self.salt = salt
 
-    def create_order(self, total_amount=1, subject="", body="", valid_time=900, thirdparty_id="", disable_msg=None, msg_page="", store_uid=""):
+    def create_order(self, pay_order_no, notify_url, total_amount=1, subject="", body="", valid_time=900, thirdparty_id="", disable_msg=None, msg_page="", store_uid=""):
         """
         :description: 服务端创建预下单
+        :param pay_order_no：商户订单号(支付单号)开发者服务端的唯一订单号
+        :param notify_url：支付结果异步通知地址
         :param total_amount:支付价格; 接口中参数支付金额单位为[分]|默认 1
         :param subject: 商品描述; 长度限制 128 字节，不超过 42 个汉字 |默认 自己约定一个比如 “福小宠商品”*|
         :param body:商品详情|默认 自己约定一个比如 “福小宠商品”
@@ -220,17 +244,9 @@ class TikTokPayRequest(object):
         """
         invoke_result_data = InvokeResultData()
         try:
-            app_id = self.app_id
-            #out_order_no 开发者服务端的唯一订单号
-            out_order_no = SevenHelper.create_order_id()
-            #回调地址
-            notify_url = self.notify_url
-            cp_extra = self.cp_extra
-            # 在这里将订单信息存入数据库
-
             data = {}
-            data['out_order_no'] = out_order_no
-            data['cp_extra'] = cp_extra
+            data['out_order_no'] = pay_order_no
+            data['cp_extra'] = self.cp_extra
             data['notify_url'] = notify_url
             data['total_amount'] = str(int(decimal.Decimal(str(total_amount)) * 100))
             data['subject'] = subject
@@ -243,45 +259,37 @@ class TikTokPayRequest(object):
             if store_uid:
                 data['store_uid'] = store_uid
 
-            sign = self.get_tt_sign(data)
+            sign = self._get_tt_sign(data)
             # 如果有第三方平台服务商id:thirdparty_id字段请把他放入data的字典里面
             data['sign'] = sign
-            data['app_id'] = app_id
+            data['app_id'] = self.app_id
 
             if thirdparty_id:
                 data['thirdparty_id'] = thirdparty_id
 
-            redis_key = "tiktok_order_id:" + str(out_order_no)
-            order_id = SevenHelper.redis_init().get(redis_key)
-            if order_id:
-                invoke_result_data.data = order_id
+            redis_key = f"{self.app_id}_tiktok_order_id:{str(pay_order_no)}"
+            orderInfo = SevenHelper.redis_init().get(redis_key)
+            if orderInfo:
+                invoke_result_data.data = SevenHelper.json_loads(orderInfo)
                 return invoke_result_data
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/create_order"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                # err_no	number	    状态码 0-业务处理成功
-                # err_tips	string	    错误提示信息，常见错误处理可参考附录常见问题章节
-                # data	    orderInfo	拉起收银台的 orderInfo
-                # {"err_no": 2000, "err_tips": "单号记录不存在", "data": null}
-                if resp['err_no'] == 0:
-                    order_id = str(resp['data']['order_id'])
-                    SevenHelper.redis_init().set(redis_key, order_id, ex=3600 * 1)
-                    invoke_result_data.data = order_id
-                    return invoke_result_data
-                else:
-                    self.logger_error.error(f"【{out_order_no},创建预下单】" + resp['err_tips'])
-                    invoke_result_data.success = False
-                    invoke_result_data.error_code="error"
-                    invoke_result_data.error_message = resp['err_tips']
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            # err_no	number	    状态码 0-业务处理成功
+            # err_tips	string	    错误提示信息，常见错误处理可参考附录常见问题章节
+            # data	    orderInfo	拉起收银台的 orderInfo
+            # {"err_no": 2000, "err_tips": "单号记录不存在", "data": null}
+            if response_data['err_no'] == 0:
+                SevenHelper.redis_init().set(redis_key, SevenHelper.json_dumps(response_data['data']), ex=3600 * 1)
+                invoke_result_data.data = response_data['data']
+                return invoke_result_data
             else:
-                self.logger_error.error(f"【{out_order_no},创建预下单】" + response.text)
+                self.logger_error.error(f"【{pay_order_no},创建预下单】" + response_data['err_tips'])
                 invoke_result_data.success = False
                 invoke_result_data.error_code="error"
-                invoke_result_data.error_message = "支付接口报错，请重试"
+                invoke_result_data.error_message = response_data['err_tips']
                 return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【创建预下单】" + str(ex))
@@ -290,10 +298,10 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "创建预下单出现异常，请重试"
             return invoke_result_data
 
-    def query_order(self, out_order_no="", thirdparty_id=""):
+    def query_order(self, pay_order_no, thirdparty_id=""):
         """
         :description: 查询订单
-        :param out_order_no：开发者侧的订单号, 不可重复
+        :param pay_order_no：开发者侧的订单号, 不可重复
         :param thirdparty_id: 服务商模式接入必传  第三方平台服务商 id，非服务商模式留空字符串|默认值 空字符串
         :last_editors: HuangJianYi
         """
@@ -301,8 +309,8 @@ class TikTokPayRequest(object):
         try:
             app_id = self.app_id
             data = {}
-            data['out_order_no'] = out_order_no
-            sign = self.get_tt_sign(data)
+            data['out_order_no'] = pay_order_no
+            sign = self._get_tt_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -310,34 +318,28 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_order"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                # {"err_no": 2000, "err_tips": "单号记录不存在", "out_order_no": "", "order_id": "", "payment_info": null}
-                # payment_info 返回值结构如下：
-                # {
-                #     "total_fee": 1200,
-                #     "order_status": "PROCESSING-处理中|SUCCESS-成功|FAIL-失败|TIMEOUT-超时",
-                #     "pay_time": "支付时间",
-                #     "way": 1,
-                #     "channel_no": "渠道单号",
-                #     "channel_gateway_no": "渠道网关号"
-                # }
-                if resp['err_no'] == 0:
-                    invoke_result_data.data = resp
-                    return invoke_result_data
-                else:
-                    self.logger_error.error(f"【{out_order_no},查询订单】" + resp['err_tips'])
-                    invoke_result_data.success = False
-                    invoke_result_data.error_code="error"
-                    invoke_result_data.error_message = resp['err_tips']
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            # {"err_no": 2000, "err_tips": "单号记录不存在", "out_order_no": "", "order_id": "", "payment_info": null}
+            # payment_info 返回值结构如下：
+            # {
+            #     "total_fee": 1200,
+            #     "order_status": "PROCESSING-处理中|SUCCESS-成功|FAIL-失败|TIMEOUT-超时",
+            #     "pay_time": "支付时间",
+            #     "way": 1,
+            #     "channel_no": "渠道单号",
+            #     "channel_gateway_no": "渠道网关号"
+            # }
+            if response_data['err_no'] == 0:
+                invoke_result_data.data = response_data
+                return invoke_result_data
             else:
-                self.logger_error.error(f"【查询订单】" + response.text)
+                self.logger_error.error(f"【{pay_order_no},查询订单】" + response_data['err_tips'])
                 invoke_result_data.success = False
                 invoke_result_data.error_code="error"
-                invoke_result_data.error_message = "查询订单出现异常，请重试"
+                invoke_result_data.error_message = response_data['err_tips']
                 return invoke_result_data
+
         except Exception as ex:
             self.logger_error.error("【查询订单】" + str(ex))
             invoke_result_data.success = False
@@ -345,10 +347,31 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "查询订单出现异常，请重试"
             return invoke_result_data
 
-    def create_refund(self, out_order_no="", refund_amount=1, reason="", thirdparty_id="", disable_msg=None, msg_page="", all_settle=None):
+    def get_pay_status(self, pay_order_no, thirdparty_id=""):
+        """
+        :description: 查询订单状态
+        :param pay_order_no：开发者侧的订单号, 不可重复
+        :param thirdparty_id: 服务商模式接入必传  第三方平台服务商 id，非服务商模式留空字符串|默认值 空字符串
+        :return: PROCESSING-处理中|SUCCESS-成功|FAIL-失败|TIMEOUT-超时
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data = self.query_order(pay_order_no, thirdparty_id)
+        if invoke_result_data.success == False:
+            return ""
+        else:
+            response_data = invoke_result_data.data
+            if response_data['payment_info']:
+                return response_data['payment_info']['order_status']
+            else:
+                return ""
+
+    def create_refund(self, refund_no, pay_order_no, notify_url, refund_amount=1, reason="", thirdparty_id="", disable_msg=None, msg_page="", all_settle=None):
         """
         :description: 服务端退款请求
-        :param out_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
+        :param refund_no:开发者侧的退款单号, 不可重复
+        :param pay_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
+        :param notify_url:退款通知地址
         :param refund_amount: 退款金额，单位[分]|默认 1
         :param reason:退款理由，长度上限 100|默认 由开发者定 例如：“7天无理由退款”
         :param thirdparty_id:服务商模式接入必传,第三方平台服务商 id，非服务商模式留空|默认传空字符串
@@ -360,18 +383,12 @@ class TikTokPayRequest(object):
         invoke_result_data = InvokeResultData()
         try:
             app_id = self.app_id
-            #out_order_no 开发者服务端的唯一订单号
-            out_refund_no = SevenHelper.create_order_id()
-            #回调地址
-            notify_url = self.notify_url
-            cp_extra = self.cp_extra
-            # 在这里将订单信息存入数据库
             data = {}
-            data['out_refund_no'] = out_refund_no
+            data['out_refund_no'] = refund_no
             #cp_extra 开发者自定义字段，回调原样回传
-            data['cp_extra'] = cp_extra
+            data['cp_extra'] =  self.cp_extra
             data['notify_url'] = notify_url
-            data['out_order_no'] = out_order_no
+            data['out_order_no'] = pay_order_no
             data['refund_amount'] = str(int(decimal.Decimal(str(refund_amount)) * 100))
             data['reason'] = reason
             if disable_msg:
@@ -381,7 +398,7 @@ class TikTokPayRequest(object):
             if all_settle:
                 data['all_settle'] = int(all_settle)
 
-            sign = self.get_tt_sign(data)
+            sign = self._get_tt_sign(data)
             # 如果有第三方平台服务商 id :thirdparty_id字段请把他放入data.update的字典里面
             data['sign'] = sign
             data['app_id'] = app_id
@@ -390,12 +407,11 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/create_refund"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                if resp['err_no'] == 0:
-                    invoke_result_data.data = resp
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data['err_no'] == 0:
+                invoke_result_data.data = response_data
+                return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【退款】" + str(ex))
             invoke_result_data.success = False
@@ -403,10 +419,10 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "退款出现异常，请重试"
             return invoke_result_data
 
-    def query_refund(self, out_refund_no="", thirdparty_id=""):
+    def query_refund(self, refund_no="", thirdparty_id=""):
         """
         :desciption:退款查询
-        :param out_refund_no:开发者侧的退款单号, 不可重复
+        :param refund_no:开发者侧的退款单号, 不可重复
         :param thirdparty_id:服务商模式接入必传  第三方平台服务商 id，非服务商模式留空字符串
         :last_editors: HuangJianYi
         """
@@ -414,8 +430,8 @@ class TikTokPayRequest(object):
         try:
             app_id = self.app_id
             data = {}
-            data['out_refund_no'] = out_refund_no
-            sign = self.get_tt_sign(data)
+            data['out_refund_no'] = refund_no
+            sign = self._get_tt_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -423,12 +439,12 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_refund"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                if resp['err_no'] == 0:
-                    invoke_result_data.data = resp
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data['err_no'] == 0:
+                invoke_result_data.data = response_data
+                return invoke_result_data
+
         except Exception as ex:
             self.logger_error.error("【退款查询】" + str(ex))
             invoke_result_data.success = False
@@ -436,10 +452,10 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "退款查询出现异常，请重试"
             return invoke_result_data
 
-    def create_settle(self, out_order_no="", settle_desc="", settle_params="", thirdparty_id=""):
+    def create_settle(self, pay_order_no="", settle_desc="", settle_params="", thirdparty_id=""):
         """
         :description:服务端结算请求
-        :param out_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
+        :param order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
         :param settle_desc:结算描述 默认 自己约定一个比如 “福小宠商品结算”
         :param settle_params:其他分账方信息，分账分配参数 SettleParameter 数组序列化后生成的 json 格式字符串
         :param thirdparty_id：服务商模式接入必传,第三方平台服务商 id，非服务商模式留空|默认传空字符串
@@ -459,11 +475,11 @@ class TikTokPayRequest(object):
             #cp_extra 开发者自定义字段，回调原样回传
             data['cp_extra'] = cp_extra
             data['notify_url'] = notify_url
-            data['out_order_no'] = out_order_no
+            data['out_order_no'] = pay_order_no
             data['settle_desc'] = settle_desc
             if settle_params:
                 data['settle_params'] = settle_params
-            sign = self.get_tt_sign(data)
+            sign = self._get_tt_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -471,12 +487,12 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/settle"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                if resp['err_no'] == 0:
-                    invoke_result_data.data = resp
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data['err_no'] == 0:
+                invoke_result_data.data = response_data
+                return invoke_result_data
+
         except Exception as ex:
             self.logger_error.error("【结算请求】" + str(ex))
             invoke_result_data.success = False
@@ -496,7 +512,7 @@ class TikTokPayRequest(object):
             app_id = self.app_id
             data = {}
             data['out_settle_no'] = out_settle_no
-            sign = self.get_tt_sign(data)
+            sign = self._get_tt_sign(data)
             data['sign'] = sign
             data['app_id'] = app_id
             if thirdparty_id:
@@ -504,12 +520,12 @@ class TikTokPayRequest(object):
 
             url = "https://developer.toutiao.com/api/apps/ecpay/v1/query_settle"
             headers = {"Content-type": "application/json"}
-            response = requests.post(url, headers=headers, data=json.dumps(data))
-            if response.status_code == 200:
-                resp = json.loads(response.text)
-                if resp['err_no'] == 0:
-                    invoke_result_data.data = resp
-                    return invoke_result_data
+            response = requests.post(url, headers=headers, data=SevenHelper.json_dumps(data))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data['err_no'] == 0:
+                invoke_result_data.data = response_data
+                return invoke_result_data
+
         except Exception as ex:
             self.logger_error.error("【结算查询】" + str(ex))
             invoke_result_data.success = False
@@ -517,7 +533,7 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "结算查询出现异常，请重试"
             return invoke_result_data
 
-    def get_tt_sign(self, params):
+    def _get_tt_sign(self, params):
         """
         :description: 获取头条请求sign
         :param params: 参数字典
@@ -542,10 +558,17 @@ class TikTokReponse(object):
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, data):
+    def __init__(self, data, token):
         self.data = data  #data由json.loads(self.request.body)获得
-        payconfig = config.get_value("tiktok_pay")
-        self.token = payconfig['token']
+        self.token = token
+
+    def get_data(self):
+        """
+        :description: 获取通知的数据
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return self.data
 
     def check_sign(self):
         """
@@ -554,7 +577,7 @@ class TikTokReponse(object):
         :last_editors: HuangJianYi
         """
         #计算服务端sign
-        service_signature = self.get_tt_callback_sign(self.data)
+        service_signature = self._get_tt_callback_sign(self.data)
         #验证成功,进行业务处理
         log_msg = f'客户端签名:{self.data["msg_signature"]},服务端签名:{service_signature}'
         # self.logger_error.error(log_msg)
@@ -563,7 +586,7 @@ class TikTokReponse(object):
         else:
             return False
 
-    def get_tt_callback_sign(self, params):
+    def _get_tt_callback_sign(self, params):
         """
         :description: 获取头条回调sign
         :param params: 参数字典
@@ -580,4 +603,44 @@ class TikTokReponse(object):
         params_list = sorted(list(params_copy.items()), key=lambda x: x[1])
         params_str = ''.join(f"{v}" for k, v in params_list)
         sign = CryptoHelper().sha1_encrypt(params_str)
-        return sign
\ No newline at end of file
+        return sign
+
+    def response_json(self, err_no=0, err_tips="success"):
+        """
+        :description: 获取通知的数据
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return {}
+
+
+class TikTokBizDataCrypt:
+    def __init__(self, app_id, session_key):
+        self.app_id = app_id
+        self.session_key = session_key
+
+    def decrypt(self, encryptedData, iv):
+        """
+        :description: 解密
+        :param encryptedData: encryptedData
+        :param iv: iv
+        :return str
+        :last_editors: HuangJianYi
+        """
+        # base64 decode
+        session_key = base64.b64decode(self.session_key)
+        encryptedData = base64.b64decode(encryptedData)
+        iv = base64.b64decode(iv)
+        decrypted = {}
+        cipher = AES.new(session_key, AES.MODE_CBC, iv)
+        result_data = str(self._unpad(cipher.decrypt(encryptedData)), "utf-8")
+        if result_data:
+            decrypted = SevenHelper.json_loads(result_data)
+        if decrypted:
+            if decrypted['watermark']['appid'] != self.app_id:
+                raise Exception('Invalid Buffer')
+
+        return decrypted
+
+    def _unpad(self, s):
+        return s[:-ord(s[len(s) - 1:])]
\ No newline at end of file
