@@ -2,10 +2,11 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-09-10 13:32:20
+@LastEditTime: 2021-09-14 19:29:48
 @LastEditors: HuangJianYi
 @Description: 
 """
+from requests_pkcs12 import post
 import requests
 from Crypto.Cipher import AES
 import base64
@@ -26,22 +27,24 @@ class WeChatHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self, code, grant_type="authorization_code"):
+    def code2_session(self,app_id, app_secret, code, grant_type="authorization_code"):
         """
         :description:临时登录凭证校验
+        :param app_id：app_id
+        :param app_secret：app_secret
         :param code：登录票据
         :param grant_type：授权方式
         :return: 返回字典包含字段 session_key,openid
         :last_editors: HuangJianYi
         """
-        redis_key = "wechat_login_code:" + str(code)
+        invoke_result_data = InvokeResultData()
+        redis_key = f"{app_id}_wechat_login_code:{str(code)}"
         redis_init = SevenHelper.redis_init()
         code2_session_dict = redis_init.get(redis_key)
         if code2_session_dict:
             code2_session_dict = SevenHelper.json_loads(code2_session_dict)
-            return code2_session_dict
-        app_id = config.get_value("app_id")
-        app_secret = config.get_value("app_secret")
+            invoke_result_data.data = code2_session_dict
+            return invoke_result_data
         param = {
             'js_code': code,  # 用户点击按钮跳转到微信授权页, 微信处理完后重定向到redirect_uri, 并给我们加上code=xxx的参数, 这个code就是我们需要的
             'appid': app_id,
@@ -51,25 +54,68 @@ class WeChatHelper:
 
         # 通过code获取access_token
         requset_url = 'https://api.weixin.qq.com/sns/jscode2session'
-        resp = None
+        respone = None
         try:
-            resp = requests.get(requset_url, params=param)
-            res_result = SevenHelper.json_loads(resp.text)
-            if res_result.errcode != 0:
-                return None
-            open_id = res_result['openid']
-            session_key = res_result['session_key']
-            redis_init.set(redis_key, SevenHelper.json_dumps(res_result), ex=60 * 60)
-            redis_init.set(f"wechat_sessionkey:{open_id}", session_key, ex=60 * 60)
-            return res_result
+            respone = requests.get(requset_url, params=param)
+            respone_data = SevenHelper.json_loads(respone.text)
+            if respone_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = respone_data["errcode"]
+                invoke_result_data.error_message = respone_data["errmsg"]
+                return invoke_result_data
+            open_id = respone_data['openid']
+            session_key = respone_data['session_key']
+            redis_init.set(redis_key, SevenHelper.json_dumps(respone_data), ex=60 * 60)
+            redis_init.set(f"{app_id}_wechat_sessionkey:{open_id}", session_key, ex=60 * 60)
+            return respone_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(resp.text))
-            return None
+            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(respone.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = str(ex)
+            return invoke_result_data
 
     @classmethod
-    def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv):
+    def get_access_token(self, app_id, app_secret, grant_type="client_credential"):
+        """
+        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param grant_type: 获取access_token 时值为 client_credential
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        param = {
+            'appid': app_id,
+            'secret': app_secret,
+            'grant_type': grant_type,
+        }
+        respone = None
+        try:
+            requset_url = 'https://api.weixin.qq.com/cgi-bin/token'
+            respone = requests.get(requset_url, params=param)
+            respone_data = SevenHelper.json_loads(respone.text)
+            if respone_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = respone_data["errcode"]
+                invoke_result_data.error_message = respone_data["errmsg"]
+                return invoke_result_data
+            invoke_result_data.data = str(respone_data["access_token"])
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【get_access_token】" + str(ex) + ":" + str(respone.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = str(ex)
+            return invoke_result_data
+
+    @classmethod
+    def decrypt_data_by_code(self, app_id, app_secret, open_id, code, encrypted_Data, iv):
         """
         :description:解析加密数据，客户端判断是否登录状态，如果登录只传open_id不传code，如果是登录过期,要传code重新获取session_key
+        :param app_id：app_id
+        :param app_secret：app_secret
         :param open_id：open_id
         :param code：登录票据
         :param encrypted_Data：加密数据,微信返回加密参数
@@ -79,11 +125,11 @@ class WeChatHelper:
         """
         data = None
         if code:
-            code2_session_dict = self.code2_session(code)
+            code2_session_dict = self.code2_session(app_id, app_secret,code)
             if code2_session_dict:
                 open_id = code2_session_dict["openid"]
         try:
-            session_key = SevenHelper.redis_init().get(f"wechat_sessionkey:{open_id}")
+            session_key = SevenHelper.redis_init().get(f"{app_id}_wechat_sessionkey:{open_id}")
             app_id = config.get_value("app_id")
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
@@ -112,7 +158,11 @@ class WeChatHelper:
 
     @classmethod
     def array_to_xml(self, array):
-        """array转xml"""
+        """
+        :description:array转xml
+        :return:
+        :last_editors: HuangJianYi
+        """
         xml = ["<xml>"]
         for k, v in array.items():
             if v.isdigit():
@@ -124,7 +174,11 @@ class WeChatHelper:
 
     @classmethod
     def xml_to_array(self, xml):
-        """将xml转为array"""
+        """
+        :description:将xml转为array
+        :return:
+        :last_editors: HuangJianYi
+        """
         array_data = {}
         root = ElementTree.fromstring(xml)
         for child in root:
@@ -132,38 +186,56 @@ class WeChatHelper:
             array_data[child.tag] = value
         return array_data
 
+    @classmethod
+    def key_value_url(self, params, url_encode):
+        """
+        :description:   将键值对转为 key1=value1&key2=value2 对参数按照key=value的格式，并按照参数名ASCII字典序排序
+        :param params：参数字典
+        :param url_encode：是否url编码 True是False否
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        slist = sorted(params)
+        buff = []
+        for k in slist:
+            v = quote(params[k]) if url_encode else params[k]
+            buff.append("{0}={1}".format(k, v))
 
-class WeChatDataCrypt:
-    """
-    :description: 微信数据解密帮助类
-    """
-    def __init__(self, app_id, session_key):
-        self.app_id = app_id
-        self.session_key = session_key
+        return "&".join(buff)
 
-    def decrypt(self, encryptedData, iv):
-        # base64 decode
-        session_key = base64.b64decode(self.session_key)
-        encryptedData = base64.b64decode(encryptedData)
-        iv = base64.b64decode(iv)
-        decrypted = {}
-        cipher = AES.new(session_key, AES.MODE_CBC, iv)
-        result_data = str(self._unpad(cipher.decrypt(encryptedData)), "utf-8")
-        if result_data:
-            decrypted = json.loads(result_data)
-        if decrypted:
-            if decrypted['watermark']['appid'] != self.app_id:
-                raise Exception('Invalid Buffer')
-        return decrypted
+    @classmethod
+    def get_nonce_str(self, length=32):
+        """
+        :description: 生成随机字符串
+        :param length：长度
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        import random
+        chars = "abcdefghijklmnopqrstuvwxyz0123456789"
+        strs = []
+        for x in range(length):
+            strs.append(chars[random.randrange(0, len(chars))])
+        return "".join(strs)
 
-    def _unpad(self, s):
-        return s[:-ord(s[len(s) - 1:])]
+    @classmethod
+    def get_sign(self, params):
+        """
+        :description:生成sign拼接API密钥
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        string_a = WeChatHelper.key_value_url(params, False)
+        string_sign_temp = string_a + '&key=' + self.api_key  # APIKEY, API密钥，需要在商户后台设置
+        sign = (hashlib.md5(string_sign_temp.encode("utf-8")).hexdigest()).upper()
+        params['sign'] = sign
+        return params
 
 
 class WeChatPayRequest(object):
     """
     :description: 微信支付请求类
-    :description: 配置文件内容 "wechat_pay": {"api_key": "","mch_id": ""}
+    :description: 配置文件内容 "wechat_pay": {"api_key": "","mch_id": "","certificate_url":""}
     """
     """配置账号信息"""
     # =======【基本信息设置】=====================================
@@ -173,14 +245,16 @@ class WeChatPayRequest(object):
     mch_id = ""
     # API密钥，需要在商户后台设置
     api_key = ""
+    # 证书地址
+    certificate_url = ""
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self):
-        pay_config = config.get_value("wechat_pay")
-        self.app_id = config.get_value("app_id")
-        self.api_key = pay_config['api_key']
-        self.mch_id = pay_config['mch_id']
+    def __init__(self, app_id, api_key, mch_id, certificate_url=""):
+        self.app_id = app_id
+        self.api_key = api_key
+        self.mch_id = mch_id
+        self.certificate_url = certificate_url
 
     def get_prepay_id(self, unifiedorder_url, params):
         """
@@ -191,36 +265,38 @@ class WeChatPayRequest(object):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        redis_key = "wechat_prepay_id:" + str(params['out_trade_no'])
+        redis_key = f"{self.app_id}_wechat_prepay_id:" + str(params['out_trade_no'])
         redis_init = SevenHelper.redis_init()
         prepay_id = redis_init.get(redis_key)
-        xml = self._get_req_xml(params)
-        respone = requests.post(unifiedorder_url, xml, headers={'Content-Type': 'application/xml'})
-        msg = respone.text.encode('ISO-8859-1').decode('utf-8')
-        xmlresp = xmltodict.parse(msg)
-        if xmlresp['xml']['return_code'] == 'SUCCESS':
-            if xmlresp['xml']['result_code'] == 'SUCCESS':
-                prepay_id = str(xmlresp['xml']['prepay_id'])
+        if prepay_id:
+            invoke_result_data.data = prepay_id
+            return invoke_result_data
+
+        respone = requests.post(unifiedorder_url, self._get_request_xml(params), headers={'Content-Type': 'application/xml'})
+        response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+        if response_data['return_code'] == 'SUCCESS':
+            if response_data['result_code'] == 'SUCCESS':
+                prepay_id = str(response_data['prepay_id'])
                 redis_init.set(redis_key, prepay_id, ex=3600 * 1)
                 invoke_result_data.data = prepay_id
                 return invoke_result_data
             else:
-                self.logger_error.error(f"【{params['out_trade_no']},统一下单获取prepay_id】" + xmlresp['xml']['err_code_des'])
+                self.logger_error.error("【预支付单号】" + SevenHelper.json_dumps(response_data))
                 invoke_result_data.success = False
                 invoke_result_data.error_code="error"
-                invoke_result_data.error_message = xmlresp['xml']['err_code_des']
+                invoke_result_data.error_message = response_data['err_code_des']
                 return invoke_result_data
         else:
-            self.logger_error.error(f"【{params['out_trade_no']},统一下单获取prepay_id】" + xmlresp['xml']['return_msg'])
+            self.logger_error.error("【预支付单号】" + SevenHelper.json_dumps(response_data))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
-            invoke_result_data.error_message = xmlresp['xml']['return_msg']
+            invoke_result_data.error_message = response_data['return_msg']
             return invoke_result_data
 
-    def create_order(self, out_trade_no, body, total_fee, spbill_create_ip, notify_url, open_id="", time_expire="", trade_type="JSAPI"):
+    def create_order(self, pay_order_no, body, total_fee, spbill_create_ip, notify_url, open_id="", time_expire="", trade_type="JSAPI"):
         """
         :description: 创建微信预订单
-        :param out_trade_no：商户订单号(支付单号)
+        :param pay_order_no：商户订单号(支付单号)
         :param body：订单描述
         :param total_fee：支付金额
         :param spbill_create_ip：客户端IP
@@ -236,9 +312,9 @@ class WeChatPayRequest(object):
         params = {
             'appid': self.app_id,  # appid
             'mch_id': self.mch_id,  # 商户号
-            'nonce_str': self._get_nonceStr(),
+            'nonce_str': WeChatHelper.get_nonce_str(),
             'body': body,
-            'out_trade_no': str(out_trade_no),
+            'out_trade_no': str(pay_order_no),
             'total_fee': str(int(decimal.Decimal(str(total_fee)) * 100)),
             'spbill_create_ip': spbill_create_ip,
             'trade_type': trade_type,
@@ -265,153 +341,191 @@ class WeChatPayRequest(object):
         params['package'] = f"prepay_id={prepay_id}"
         params['timestamp'] = str(int(time.time()))
         sign_again_params = {'appId': params['appid'], 'nonceStr': params['nonce_str'], 'package': params['package'], 'signType': 'MD5', 'timeStamp': params['timestamp']}
-        invoke_result_data.data = self._get_sign(sign_again_params)
+        invoke_result_data.data = WeChatHelper.get_sign(sign_again_params)
         return invoke_result_data  # 返回给app
 
-    def query_order(self, out_trade_no="", transaction_id=""):
+    def query_order(self, pay_order_no="", transaction_id=""):
         """
         :description: 查询订单
         :param transaction_id：微信订单号
-        :param out_trade_no：商户订单号(支付单号)
+        :param pay_order_no：商户订单号(支付单号)
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if transaction_id == "" and out_trade_no == "":
+        if transaction_id == "" and pay_order_no == "":
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
-            invoke_result_data.error_message = "缺少必填参数transaction_id或out_trade_no"
+            invoke_result_data.error_message = "缺少必填参数transaction_id或pay_order_no"
             return invoke_result_data
-        xmlresp = {}
-        xml = ""
+        request_xml = ""
         try:
             params = {
-                'appid': self.app_id,  # appid
-                'mch_id': self.mch_id,  # 商户号
-                'nonce_str': self._get_nonceStr(),
+                'appid': self.app_id,
+                'mch_id': self.mch_id,
+                'nonce_str': WeChatHelper.get_nonce_str(),
             }
             if transaction_id != "":
-                params['transaction_id'] = str(transaction_id)  # 微信交易单号
-            if out_trade_no != "":
-                params['out_trade_no'] = str(out_trade_no)  # 支付单号
+                params['transaction_id'] = str(transaction_id)
+            if pay_order_no != "":
+                params['out_trade_no'] = str(pay_order_no)
 
-            xml = self._get_req_xml(params)
-            queryorder_url = 'https://api.mch.weixin.qq.com/pay/orderquery'  # 微信请求url
-            respone = requests.post(queryorder_url, xml, headers={'Content-Type': 'application/xml'})
-            msg = respone.text.encode('ISO-8859-1').decode('utf-8')
-            xmlresp = xmltodict.parse(msg)
+            request_xml = self._get_request_xml(params)
+            queryorder_url = 'https://api.mch.weixin.qq.com/pay/orderquery'
+            respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
+            response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+            invoke_result_data.data = response_data
+            return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【查询订单】" + str(ex) + ":" + str(xml))
+            self.logger_error.error("【查询订单】" + str(ex) + ":" + str(request_xml))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "查询订单出现异常"
             return invoke_result_data
-        invoke_result_data.data = xmlresp
-        return invoke_result_data
 
-    def close_order(self, out_trade_no=""):
+    def close_order(self, pay_order_no=""):
         """
         :description: 关闭订单
-        :param out_trade_no：商户订单号(支付单号)
+        :param pay_order_no：商户订单号(支付单号)
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if out_trade_no == "":
+        if pay_order_no == "":
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
-            invoke_result_data.error_message = "缺少必填参数out_trade_no"
+            invoke_result_data.error_message = "缺少必填参数pay_order_no"
             return invoke_result_data
-        xmlresp = {}
+        request_xml = ""
         try:
             params = {
-                'appid': self.app_id,  # appid
-                'mch_id': self.mch_id,  # 商户号
-                'nonce_str': self._get_nonceStr(),
-                'out_trade_no': str(out_trade_no)  # 支付单号
+                'appid': self.app_id,
+                'mch_id': self.mch_id,
+                'nonce_str': WeChatHelper.get_nonce_str(),
+                'out_trade_no': str(pay_order_no)
             }
-            xml = self._get_req_xml(params)
-            queryorder_url = 'https://api.mch.weixin.qq.com/pay/closeorder'  # 微信请求url
-            respone = requests.post(queryorder_url, xml, headers={'Content-Type': 'application/xml'})
-            msg = respone.text.encode('ISO-8859-1').decode('utf-8')
-            xmlresp = xmltodict.parse(msg)
-            invoke_result_data.data = xmlresp
+            request_xml = self._get_request_xml(params)
+            queryorder_url = 'https://api.mch.weixin.qq.com/pay/closeorder'
+            respone = requests.post(queryorder_url, request_xml, headers={'Content-Type': 'application/xml'})
+            response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+            invoke_result_data.data = response_data
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【关闭订单】" + str(ex))
+            self.logger_error.error("【关闭订单】" + str(ex) + ":" + str(request_xml))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "关闭订单出现异常"
             return invoke_result_data
 
-    def get_pay_status(self, out_trade_no, transaction_id=""):
+    def get_pay_status(self, pay_order_no, transaction_id=""):
         """
         :description: 查询订单状态
+        :param pay_order_no：商户订单号(支付单号)
         :param transaction_id：微信订单号
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        invoke_result_data = self.query_order(out_trade_no, transaction_id)
+        invoke_result_data = self.query_order(pay_order_no, transaction_id)
         if invoke_result_data.success == False:
             return ""
         else:
-            xmlresp = invoke_result_data.data
-            if xmlresp['xml']['return_code'] == 'SUCCESS':
-                if xmlresp['xml']['result_code'] == 'SUCCESS':
-                    return str(xmlresp['xml']['trade_state'] if xmlresp['xml'].__contains__("trade_state") else "")  # SUCCESS--支付成功REFUND--转入退款NOTPAY--未支付CLOSED--已关闭REVOKED--已撤销(刷卡支付)USERPAYING--用户支付中PAYERROR--支付失败(其他原因，如银行返回失败)ACCEPT--已接收，等待扣款
+            response_data = invoke_result_data.data
+            if response_data['return_code'] == 'SUCCESS':
+                if response_data['result_code'] == 'SUCCESS':
+                    return str(response_data['trade_state'] if response_data.__contains__("trade_state") else "")  # SUCCESS--支付成功REFUND--转入退款NOTPAY--未支付CLOSED--已关闭REVOKED--已撤销(刷卡支付)USERPAYING--用户支付中PAYERROR--支付失败(其他原因，如银行返回失败)ACCEPT--已接收，等待扣款
                 else:
                     return ""
             else:
                 return ""
 
-    def _get_nonceStr(self, length=32):
+    def create_refund(self, refund_no, pay_order_no, notify_url, refund_fee, total_fee):
         """
-        :description: 生成随机字符串
-        :param transaction_id：微信订单号
+        :description: 服务端退款请求
+        :param refund_no:开发者侧的退款单号, 不可重复
+        :param pay_order_no:商户分配订单号，标识进行退款的订单，开发者服务端的唯一订单号
+        :param notify_url:退款通知地址
+        :param refund_fee: 退款金额，单位[分]
+        :param total_fee：支付金额
         :return: 
         :last_editors: HuangJianYi
         """
-        import random
-        chars = "abcdefghijklmnopqrstuvwxyz0123456789"
-        strs = []
-        for x in range(length):
-            strs.append(chars[random.randrange(0, len(chars))])
-        return "".join(strs)
+        invoke_result_data = InvokeResultData()
+        params = {
+            'appid': self.app_id,  # appid
+            'mch_id': self.mch_id,  # 商户号
+            'nonce_str': WeChatHelper.get_nonce_str(),
+            'out_trade_no': str(pay_order_no),
+            'out_refund_no': str(refund_no),
+            'notify_url': notify_url,
+            'refund_fee': int(decimal.Decimal(str(refund_fee)) * 100),
+            'sign_type': 'MD5',
+            'total_fee': int(decimal.Decimal(str(total_fee)) * 100),
+        }
+        params = WeChatHelper.get_sign(params)
+        refund_url = 'https://api.mch.weixin.qq.com/secapi/pay/refund'
+        respone = post(url=refund_url, data=self._get_request_xml(params), headers={'Content-Type': 'application/xml'}, pkcs12_filename=self.certificate_url, pkcs12_password=self.mch_id)
+        response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+        if response_data['return_code'] == 'SUCCESS':
+            if response_data['result_code'] == 'SUCCESS':
+                invoke_result_data.data = response_data['refund_id']
+                return invoke_result_data
+            else:
+                self.logger_error.error("【创建退款单】" + SevenHelper.json_dumps(response_data))
+                invoke_result_data.success = False
+                invoke_result_data.error_code="error"
+                invoke_result_data.error_message = response_data['err_code_des']
+                return invoke_result_data
+        else:
+            self.logger_error.error("【创建退款单】" + SevenHelper.json_dumps(response_data))
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = response_data['return_msg']
+            return invoke_result_data
 
-    def _key_value_url(self, value, urlencode):
+    def query_refund(self, refund_no):
         """
-        :description:   将键值对转为 key1=value1&key2=value2 对参数按照key=value的格式，并按照参数名ASCII字典序排序
+        :description: 查询退款单
+        :param refund_no：商户退款单号
         :return: 
         :last_editors: HuangJianYi
         """
-        slist = sorted(value)
-        buff = []
-        for k in slist:
-            v = quote(value[k]) if urlencode else value[k]
-            buff.append("{0}={1}".format(k, v))
+        invoke_result_data = InvokeResultData()
+        if refund_no == "":
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "缺少必填参数refund_no"
+            return invoke_result_data
+        request_xml = ""
+        try:
+            params = {
+                'appid': self.app_id,
+                'mch_id': self.mch_id,
+                'nonce_str': WeChatHelper.get_nonce_str(),
+                'out_refund_no': str(refund_no),
+                'sign_type': 'MD5'
+            }
+            params = WeChatHelper.get_sign(params)
+            request_xml = self._get_request_xml(params)
+            queryrefund_url = 'https://api.mch.weixin.qq.com/pay/refundquery'
+            respone = requests.post(queryrefund_url, request_xml, headers={'Content-Type': 'application/xml'})
+            response_data = xmltodict.parse(respone.text.encode('ISO-8859-1').decode('utf-8'))['xml']
+            invoke_result_data.data = response_data
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【查询退款单】" + str(ex) + ":" + str(request_xml))
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "查询退款单出现异常"
+            return invoke_result_data
 
-        return "&".join(buff)
-
-    def _get_sign(self, params):
-        """
-        :description:生成sign拼接API密钥
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        stringA = self._key_value_url(params, False)
-        stringSignTemp = stringA + '&key=' + self.api_key  # APIKEY, API密钥，需要在商户后台设置
-        sign = (hashlib.md5(stringSignTemp.encode("utf-8")).hexdigest()).upper()
-        params['sign'] = sign
-        return params
-
-    def _get_req_xml(self, params):
+    def _get_request_xml(self, params):
         """
         :description:拼接XML
         :return: 
         :last_editors: HuangJianYi
         """
-        params = self._get_sign(params)
+        params = WeChatHelper.get_sign(params)
         xml = "<xml>"
         for k, v in params.items():
             # v = v.encode('utf8')
@@ -428,40 +542,9 @@ class WeChatPayReponse(object):
 
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, reponse_xml):
-        pay_config = config.get_value("wechat_pay")
-        self.data = WeChatHelper.xml_to_array(reponse_xml)  # 接收到的数据，类型为关联数组
-        self.api_key = pay_config['api_key']
-
-    def _format_bizquery_paramap(self, paraMap, urlencode):
-        """
-        :description: 格式化参数，签名过程需要使用
-        :return:
-        :last_editors: HuangJianYi
-        """
-        slist = sorted(paraMap)
-        buff = []
-        for k in slist:
-            v = quote(paraMap[k]) if urlencode else paraMap[k]
-            buff.append("{0}={1}".format(k, v))
-        return "&".join(buff)
-
-    def _get_sign(self, obj):
-        """
-        :description: 生成签名
-        :return:
-        :last_editors: HuangJianYi
-        """
-        # 签名步骤一：按字典序排序参数,format_bizquery_paramap已做
-        String = self._format_bizquery_paramap(obj, False)
-        # 签名步骤二：在string后加入KEY
-        String = "{0}&key={1}".format(String, self.api_key)
-        # 签名步骤三：MD5加密
-        # String = hashlib.md5(String).hexdigest()
-        String = hashlib.md5(String.encode("utf-8")).hexdigest()
-        # 签名步骤四：所有字符转为大写
-        result_ = String.upper()
-        return result_
+    def __init__(self, reponse_xml, api_key):
+        self.data = WeChatHelper.xml_to_array(reponse_xml)
+        self.api_key = api_key
 
     def check_sign(self):
         """
@@ -469,9 +552,9 @@ class WeChatPayReponse(object):
         :return:
         :last_editors: HuangJianYi
         """
-        tmpData = dict(self.data)  # make a copy to save sign
-        del tmpData['sign']
-        sign = self._get_sign(tmpData)  # 本地签名
+        params = dict(self.data)  # make a copy to save sign
+        del params['sign']
+        sign = WeChatHelper.get_sign(params)  # 本地签名
         if self.data['sign'] == sign:
             return True
         return False
@@ -484,7 +567,7 @@ class WeChatPayReponse(object):
         """
         return self.data
 
-    def get_return_data(self, msg, ok=True):
+    def response_xml(self, msg, ok=True):
         """
         :description: 返回xml格式数据
         :return:
@@ -500,10 +583,9 @@ class WeChatRefundReponse(object):
     """
     logger_error = Logger.get_logger_by_name("log_error")
 
-    def __init__(self, reponse_xml):
-        pay_config = config.get_value("wechat_pay")
-        self.data = xmltodict.parse(reponse_xml)  # 接收到的数据
-        self.api_key = pay_config['api_key']
+    def __init__(self, reponse_xml, api_key):
+        self.data = WeChatHelper.xml_to_array(reponse_xml)
+        self.api_key = api_key
 
     def get_data(self):
         """
@@ -523,6 +605,33 @@ class WeChatRefundReponse(object):
         dict_req_info = xmltodict.parse(detail_info)
         return dict_req_info
 
-    def get_return_data(self, msg, ok=True):
+    def response_xml(self, msg, ok=True):
         code = "SUCCESS" if ok else "FAIL"
         return WeChatHelper.array_to_xml(dict(return_code=code, return_msg=msg))
+
+
+class WeChatDataCrypt:
+    """
+    :description: 微信数据解密帮助类
+    """
+    def __init__(self, app_id, session_key):
+        self.app_id = app_id
+        self.session_key = session_key
+
+    def decrypt(self, encryptedData, iv):
+        # base64 decode
+        session_key = base64.b64decode(self.session_key)
+        encryptedData = base64.b64decode(encryptedData)
+        iv = base64.b64decode(iv)
+        decrypted = {}
+        cipher = AES.new(session_key, AES.MODE_CBC, iv)
+        result_data = str(self._unpad(cipher.decrypt(encryptedData)), "utf-8")
+        if result_data:
+            decrypted = SevenHelper.json_loads(result_data)
+        if decrypted:
+            if decrypted['watermark']['appid'] != self.app_id:
+                raise Exception('Invalid Buffer')
+        return decrypted
+
+    def _unpad(self, s):
+        return s[:-ord(s[len(s) - 1:])]
\ No newline at end of file
