@@ -279,7 +279,7 @@ class ActBaseModel():
             invoke_result_data.error_message = "活动信息不存在"
             return invoke_result_data
         is_release = 0 if is_del == 1 else 1
-        modify_date = self.get_now_datetime()
+        modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_info_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, act_id])
         self._delete_act_info_dependency_key(app_id,act_id)
         return invoke_result_data
