@@ -2,13 +2,11 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2021-08-19 13:29:09
+@LastEditTime: 2021-08-26 10:28:51
 @LastEditors: HuangJianYi
 :Description: 数据库基础操作类
 """
-import datetime
 import json
-import os
 from copy import deepcopy
 from seven_framework.base_model import *
 from seven_framework import *
@@ -19,7 +17,7 @@ class CacheModel(BaseModel):
 
     def __init__(self, model_class, sub_table):
         """
-        :Description: 数据缓存操作模型类
+        :Description: 数据缓存业务模型
         :param model_class: 实体对象类
         :param sub_table: 分表标识
         :last_editors: HuangJianYi
@@ -50,8 +48,11 @@ class CacheModel(BaseModel):
         """
         params_str = ""
         if params:
-            for param in params:
-                params_str += "_" + str(param)
+            if isinstance(params,list):
+                for param in params:
+                    params_str += "_" + str(param)
+            else:
+                params_str += "_" + str(params)
         cache_key = str(where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
         return CryptoHelper.md5_encrypt(cache_key)
         
