@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2021-08-19 15:12:52
+@LastEditTime: 2021-09-02 17:10:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,7 +26,7 @@ class PrizeOrder:
 
     def __init__(self):
         super(PrizeOrder, self).__init__()
-        self.id = 0  # id(order_no)md5int生成
+        self.id = 0  # id
         self.order_no = ""  # 订单号
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
@@ -45,7 +45,6 @@ class PrizeOrder:
         self.express_no = ""  # 快递单号
         self.express_company = ""  # 快递公司
         self.order_status = 0  # 订单状态（-1未付款-2付款中0未发货1已发货2不予发货3已退款4交易成功）
-
         self.buyer_remark = ""  # 买家备注
         self.seller_remark = ""  # 卖家备注
         self.is_free_freight = 0  # 是否包邮
