@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2021-09-06 16:40:30
+@LastEditTime: 2021-09-08 11:28:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -209,7 +209,7 @@ class FrameBaseModel():
         if user_info_dict["user_state"] == 1:
             invoke_result_data.success = False
             invoke_result_data.error_code = "user_exception"
-            invoke_result_data.error_message = "账号异常,无法操作"
+            invoke_result_data.error_message = "账号异常,请联系客服处理"
             return invoke_result_data
         if check_new_user == True and user_info_dict["is_new"] == 0:
                 invoke_result_data.success = False
