@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2021-08-26 10:29:36
+@LastEditTime: 2021-09-07 14:49:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -57,12 +57,14 @@ class ModuleBaseModel():
                 return None
         return act_module_dict
 
-    def get_act_module_list(self,app_id,act_id,module_name,is_del,page_size,page_index,is_cache=True):
+    def get_act_module_list(self,app_id,act_id,module_name,start_date,end_date,is_del,page_size,page_index,is_cache=True):
         """
         :description: 获取活动信息列表
         :param app_id: 应用标识
         :param act_id: 活动标识
         :param module_name: 模块名称
+        :param start_date：开始时间
+        :param end_date：结束时间
         :param is_del: 是否回收站1是0否
         :param page_size: 条数
         :param page_index: 页数
@@ -79,6 +81,12 @@ class ModuleBaseModel():
         if module_name:
             condition += " and module_name=%s"
             params.append(module_name)
+        if start_date != "":
+            condition += " and start_date>=%s"
+            params.append(start_date)
+        if end_date != "":
+            condition += " and end_date<=%s"
+            params.append(end_date)
         if is_cache:
             page_list, total = ActModuleModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_module_list:actid_{act_id}")
         else:
@@ -130,7 +138,7 @@ class ModuleBaseModel():
         old_act_module = None
         now_datetime = SevenHelper.get_now_datetime()
         act_module_model = ActModuleModel(context=self.context)
-       
+        act_module = None
         if module_id > 0:
             act_module = act_module_model.get_entity_by_id(module_id)
             if not act_module or act_module.app_id != app_id:
@@ -204,7 +212,7 @@ class ModuleBaseModel():
             invoke_result_data.error_message = "活动模块信息不存在"
             return invoke_result_data
         is_release = 0 if is_del == 1 else 1
-        modify_date = self.get_now_datetime()
+        modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_module_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, module_id])
         self._delete_act_module_dependency_key(act_module_dict.act_id,module_id)
         return invoke_result_data
