@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-09 11:58:01
+@LastEditTime: 2021-09-10 17:14:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -271,8 +271,8 @@ class OrderBaseModel(FrameBaseModel):
             express_company = row[express_company_index]
             if order_no and express_no and express_company:
                 now_datetime = SevenHelper.get_now_datetime()
-                update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s,modify_date=%s"
-                params = [express_company, express_no, now_datetime, now_datetime, app_id,act_id,order_no]
+                update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s"
+                params = [express_company, express_no, now_datetime, app_id,act_id,order_no]
                 prize_order_model.update_table(update_sql, "app_id=%s and act_id=%s and order_no=%s", params)
                 prize_roster_model.update_table("logistics_status=1", "app_id=%s and act_id=%s and order_no=%s", [app_id,act_id,order_no])
 
