@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2021-08-10 18:20:09
+@LastEditTime: 2021-08-26 10:29:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,7 @@ from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
 
 class PriceBaseModel():
     """
-    :description: 价格档位基类
+    :description: 价格档位业务模型
     """
     def __init__(self, context):
         self.context = context
