@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-09-07 10:09:55
+@LastEditTime: 2021-09-08 19:18:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -94,7 +94,7 @@ class PrizeBaseModel():
             page_list, total = act_prize_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)    
         return page_list, total
 
-    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
+    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,surplus,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
         """
         :description: 保存活动模块信息
         :param app_id: 应用标识
@@ -115,7 +115,7 @@ class PrizeBaseModel():
         :param chance: 概率
         :param prize_limit: 中奖限制数
         :param is_prize_notice: 是否显示跑马灯(1是0否)
-        :param prize_total: 奖品总数
+        :param surplus: 当前库存
         :param is_surplus: 是否显示奖品库存（1显示0-不显示）
         :param lottery_type: 出奖类型（1概率出奖 2强制概率）
         :param tag_name: 标签名称(奖项名称)
@@ -149,9 +149,9 @@ class PrizeBaseModel():
         
         is_add = False
         old_act_prize = None
+        act_prize = None
         now_datetime = SevenHelper.get_now_datetime()
         act_prize_model = ActPrizeModel(context=self.context)
-    
         if prize_id > 0:
             act_prize = act_prize_model.get_entity_by_id(prize_id)
             if not act_prize or act_prize.app_id != app_id:
@@ -183,7 +183,6 @@ class PrizeBaseModel():
         act_prize.prize_limit = prize_limit
         act_prize.is_prize_notice = is_prize_notice
         act_prize.is_surplus = is_surplus
-        act_prize.prize_total = prize_total
         act_prize.lottery_type = lottery_type
         act_prize.tag_name = tag_name
         act_prize.tag_id = tag_id
@@ -206,16 +205,16 @@ class PrizeBaseModel():
         act_prize.modify_date = now_datetime
         
         # 奖品类型为参与奖时
-        prize_total = 9999 if prize_type == 4 else prize_total
+        surplus = 9999 if prize_type == 4 else surplus
         
         if is_add:
             act_prize.create_date = now_datetime
-            act_prize.surplus = prize_total
-            act_prize.prize_total = prize_total
+            act_prize.surplus = surplus
+            act_prize.prize_total = surplus
             act_prize.id = act_prize_model.add_entity(act_prize)
         else:
             act_prize_model.update_entity(act_prize,exclude_field_list="app_id,act_id,module_id,prize_total,surplus,hand_out")
-            operate_num = prize_total - act_prize.prize_total
+            operate_num = surplus - act_prize.prize_total
             if operate_num != 0:
                 act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
             
@@ -278,8 +277,8 @@ class PrizeBaseModel():
             return invoke_result_data
         is_release = 0 if is_del == 1 else 1
         modify_date = SevenHelper.get_now_datetime()
-        invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict.act_id,prize_id)
+        invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, prize_id])
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
     
     def release_act_prize(self,app_id,prize_id,is_release):
@@ -299,8 +298,9 @@ class PrizeBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "活动奖品不存在"
             return invoke_result_data
-        invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict.act_id,prize_id)
+        modify_date = SevenHelper.get_now_datetime()
+        invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, prize_id])
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
 
     
