@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-:Author: HuangJingCan
+:Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2021-07-26 16:31:17
+@LastEditTime: 2021-08-26 10:30:01
 @LastEditors: HuangJianYi
-:description: 自定义实体
+:description: 自定义实体模型
 """
 
 class InvokeResult():
@@ -12,7 +12,7 @@ class InvokeResult():
     :description: 接口返回实体
     :param {type} 
     :return: InvokeResult
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     def __init__(self):
         self.success = True
@@ -24,7 +24,7 @@ class InvokeResultData():
     :description: 接口返回实体
     :param {type} 
     :return: 
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     def __init__(self):
         self.success = True
@@ -38,7 +38,7 @@ class FileUploadInfo():
     :description: 文件上传信息实体
     :param {type} 
     :return: FileUploadInfo
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     def __init__(self):
         # 检查值
@@ -63,7 +63,7 @@ class PageInfo():
     :param record_count：总记录数
     :param data：数据
     :return: PageInfo
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     def __init__(self, page_index=0, page_size=10, record_count=0, data=None):
         """
@@ -73,7 +73,7 @@ class PageInfo():
         :param record_count：总记录数
         :param data：数据
         :return: PageInfo
-        :last_editors: HuangJingCan
+        :last_editors: HuangJianYi
         """
         # 数据
         self.data = data
@@ -121,7 +121,7 @@ class PageInfo():
 class TaoBaoParam():
     """
     :description: 淘宝参数实体
-    :last_editors: HuangJingCan
+    :last_editors: HuangJianYi
     """
     def __init__(self):
         # 商家应用的appKey
