@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2021-09-06 15:29:58
+@LastEditTime: 2021-09-06 19:40:28
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -193,7 +193,7 @@ class TopBaseModel():
                 if "miniapp_template_onlineapp_response" in online_app_info.keys():
                     app_info.app_ver = resp["miniapp_template_updateapp_response"]["app_version"]
                     app_info.template_ver = client_ver
-                    app_info.modify_date = self.get_now_datetime()
+                    app_info.modify_date = SevenHelper.get_now_datetime()
                     AppInfoModel(context=self.context).update_entity(app_info, "app_ver,template_ver,modify_date")
             return invoke_result_data
         except Exception as ex:
