@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-10 11:35:33
+@LastEditTime: 2021-09-14 14:47:20
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -11,11 +11,22 @@ from seven_framework.web_tornado.monitor import MonitorHandler
 from seven_cloudapp_frame.handlers.core import *
 from seven_cloudapp_frame.handlers.server import *
 from seven_cloudapp_frame.handlers.client import *
+from seven_cloudapp_frame.handlers.w_client import *
+from seven_cloudapp_frame.handlers.t_client import *
+
 
 def seven_cloudapp_frame_route():
     return [
         (r"/monitor", MonitorHandler),
         (r"/", IndexHandler),
+        #微信客户端
+        (r"/w_cleint/voucher_order", w_pay.VoucherOrderHandler),  #创建微信预订单
+        (r"/w_cleint/pay_notify", w_pay.PayNotifyHandler),  #微信支付异步同步
+        (r"/w_cleint/refund_notify", w_pay.RefundNotifyHandler),  #微信退款异步同步
+        #抖音客户端
+        (r"/t_cleint/voucher_order", t_pay.VoucherOrderHandler),  #创建抖音预订单
+        (r"/t_cleint/pay_notify", t_pay.PayNotifyHandler),  #抖音支付异步同步
+        (r"/t_cleint/refund_notify", t_pay.RefundNotifyHandler),  #抖音退款异步同步
         #淘宝客户端
         (r"/client/address_list", address.AddressInfoListHandler),  #收货地址列表
         (r"/client/login", user.LoginHandler),  #小程序登录
